#
# spec file for package cni-plugins
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         cni_bin_dir  %{_libexecdir}/cni
%define         cni_doc_dir  %{_docdir}/cni-plugins

Name:           cni-plugins
Version:        0.7.4
Release:        lp151.1.5
Summary:        Container Network Interface plugins
License:        Apache-2.0
Group:          System/Management
Url:            https://github.com/containernetworking/plugins
Source:         %{name}-%{version}.tar.xz
BuildRequires:  go >= 1.11
BuildRequires:  golang-packaging
BuildRequires:  golang-packaging
BuildRequires:  shadow
BuildRequires:  systemd-rpm-macros
BuildRequires:  xz
BuildRequires:  golang(API) >= 1.11
Requires:       cni
Requires(post): %fillup_prereq
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}
# Make sure that the binary is not getting stripped.
%{go_nostrip}

%description
The CNI (Container Network Interface) project consists of a
specification and libraries for writing plugins to configure
network interfaces in Linux containers, along with a number of
supported plugins. CNI concerns itself only with network
connectivity of containers and removing allocated resources when
the container is deleted. Because of this focus, CNI has a wide
range of support and the specification is simple to implement.

These are the additional CNI network plugins provided by
the containernetworking team.

%prep
%setup -q

%build
./build.sh

%install

# install the plugins
install -m 755 -d "%{buildroot}%{cni_bin_dir}"
cp bin/* "%{buildroot}%{cni_bin_dir}/"

# documentation
install -m 755 -d "%{buildroot}%{cni_doc_dir}"

# TODO: copy the READMEs
#for i in plugins/main/*/README.md ; do
#      cp Documentation/* %{buildroot}%{cni_doc_dir}/plugins/
#done

%post
%{fillup_only -n %{name}}

%files
%defattr(-,root,root)
%dir %{cni_doc_dir}
%doc CONTRIBUTING.md
%doc README.md
%license LICENSE
%dir %{cni_bin_dir}
%{cni_bin_dir}/*
# %{cni_doc_dir}/plugins/*

%changelog
* Fri Jan 25 2019 Sascha Grunert <sgrunert@suse.com>
- Updated plugins to v0.7.4:
  - Add host-device plugin, which simply moves a device from the
    host network namespace
  - Portmap now uses a more efficient rule structure
  - host-local can receive ranges as a RuntimeArgument
  - DHCP daemon can be containerized
  - DHCP now correctly parses routes
  - Various Windows build fixes
  - Waiting for DAD is skipped when possible
  - Bridge now uses a stable mac
  - Fix a regression where the interface's MAC address was no
    longer populated in the return type.
* Wed Dec 12 2018 alvaro.saurin@suse.com
- Updated to a supported version of Go (due to security reasons)
* Tue Jun  5 2018 dcassany@suse.com
- Refactor %%license usage to a simpler form
* Mon Jun  4 2018 dcassany@suse.com
- Make use of %%license macro
* Tue Dec 19 2017 alvaro.saurin@suse.com
- Require cni
* Mon Aug 28 2017 alvaro.saurin@suse.com
- Install docs in the cni-plugins dir
* Mon Aug 28 2017 alvaro.saurin@suse.com
- Initial version from CNI plugins v0.6.0
